summaryrefslogtreecommitdiff
path: root/src/HTML5/Serializer/RulesInterface.php
diff options
context:
space:
mode:
Diffstat (limited to 'src/HTML5/Serializer/RulesInterface.php')
-rw-r--r--src/HTML5/Serializer/RulesInterface.php12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/HTML5/Serializer/RulesInterface.php b/src/HTML5/Serializer/RulesInterface.php
index 18ac8ca..86f44af 100644
--- a/src/HTML5/Serializer/RulesInterface.php
+++ b/src/HTML5/Serializer/RulesInterface.php
@@ -3,14 +3,14 @@
* @file
* The interface definition for Rules to generate output.
*/
-namespace HTML5\Serializer;
+namespace Masterminds\HTML5\Serializer;
/**
* To create a new rule set for writing output the RulesInterface needs to be
* implemented. The resulting class can be specified in the options with the
* key of rules.
*
* For an example implementation see \HTML5\Serializer\OutputRules.
*/
interface RulesInterface {
@@ -31,12 +31,12 @@ interface RulesInterface {
*
* Note, only one traverser can be used by the rules.
*
- * @param \HTML5\Serializer\Traverser $traverser
+ * @param \Masterminds\HTML5\Serializer\Traverser $traverser
* The traverser used in the rules.
- * @return \HTML5\Serializer\RulesInterface
+ * @return \Masterminds\HTML5\Serializer\RulesInterface
* $this for the current object.
*/
- public function setTraverser(\HTML5\Serializer\Traverser $traverser);
+ public function setTraverser(\Masterminds\HTML5\Serializer\Traverser $traverser);
/**
* Write a document element (\DOMDocument).
@@ -91,7 +91,7 @@ interface RulesInterface {
/**
* Write a processor instruction.
*
* To learn about processor instructions see \HTML5\InstructionProcessor
*
* Instead of returning the result write it to the output stream ($output)
* that was passed into the constructor.
@@ -3,14 +3,14 @@
* key of rules.
*
- * For an example implementation see \HTML5\Serializer\OutputRules.
+ * For an example implementation see \Masterminds\HTML5\Serializer\OutputRules.
*/
interface RulesInterface {
@@ -91,7 +91,7 @@ interface RulesInterface {
* Write a processor instruction.
*
- * To learn about processor instructions see \HTML5\InstructionProcessor
+ * To learn about processor instructions see \Masterminds\HTML5\InstructionProcessor
*
* Instead of returning the result write it to the output stream ($output)